
=======
Skyflow
=======

This is the Python SDK for the `Skyflow API <https://skyflow.com/>`_.

Getting Started
---------------
You can install the package using the following command ::

$ pip install skyflow

What you need
-------------
- A Skyflow account (You can also request for a demo `here <https://www.skyflow.com/get-demo>`_)

- A Skyflow Service Account

Resources
---------
- You can find the source code with examples at the official `Github <https://github.com/skyflowapi/skyflow-python/>`_ repository.
- Checkout the official `Skyflow docs <https://docs.skyflow.com/>`_ for API Reference
